<?php
	/*
	Plugin Name: PuzzleMe for WordPress
	Version: 1.1.0
	Description: Embed PuzzleMe puzzles in your posts and pages with a shortcode
	Author: Amuse Labs
	Author URI: https://www.amuselabs.com/
	License: GPLv2 or later
	License URI: https://www.gnu.org/licenses/gpl-2.0.html
	*/
	function puzzleme_iframe_generator( $attributes ) {
		if ( empty( $attributes ) ) {
			return "Parameters are missing in the shortcode. Please copy the correct shortcode from your PuzzleMe dashboard.";
		} elseif ( ($attributes['set'] != '') && ($attributes['type'] != '') ) { // If set and puzzle type information is present
			// Retrive and encode the full URL of the container page/post
			$current_page_url= urlencode( get_the_permalink() );
			// Specify allowed HTML tags in embed code
			$allowedHTMLtags = array(
				'iframe' => array(
					'height' => true,
					'width' => true,
					'allowfullscreen' => true,
					'style' => true,
					'name' => true,
					'src' => true
				)
			);
			$valid_puzzle_types = array( 'crossword', 'sudoku', 'wordsearch', 'quiz', 'krisskross', 'wordf', 'codeword', 'wordrow', 'jigsaw' );
			$valid_picker_types = array( 'date-picker' );
			// Generates basic embed code
			$iframe_html = '<iframe height="700" width="100%" allowfullscreen="true" style="border:none;width: 100% !important;position: static;display: block !important;margin: 0 !important;" name="' .sanitize_text_field( $attributes['set'] ) .'" src="';
			// Checks if a valid type is embedded
			if ( (in_array( $attributes['type'], $valid_puzzle_types )) ||  (in_array( $attributes['type'], $valid_picker_types ))) {
				// Compose basic URL
				$iframe_source = 'https://amuselabs.com/pmm/' .sanitize_text_field( $attributes['type'] ) .'?set=' .sanitize_text_field( $attributes['set'] );
				if ( in_array( $attributes['type'], $valid_puzzle_types ) )  {
					if ( $attributes['id'] != '' ) {
						$iframe_source .= '&id=' .sanitize_text_field( $attributes['id'] );
					} else {
						return "Puzzle ID is missing in the shortcode. Please use the correct shortcode from your PuzzleMe dashboard.";
					}
				} else {
					// Append puzzle ID if accessed via a deeplink
					if ( isset( $_GET['id'] ) ) {
						$iframe_source .= '&id='.sanitize_text_field( $_GET['id'] );
					}
					// Append puzzle type if accessed via a deeplink
					if ( (isset( $_GET['puzzleType'] )) ) {
						$iframe_source .= '&puzzleType='.sanitize_text_field( $_GET['puzzleType'] );
					}
				}
				// Append play ID if accessed via a social play link
				if ( (isset( $_GET['playId'] )) ) {
					$iframe_source .= '&playId='.sanitize_text_field( $_GET['playId'] );
				}
				// Append parent page URL iframe URL to embed code
				$iframe_source .= '&embed=wp&src=' . $current_page_url;
				$iframe_html .= esc_url_raw( $iframe_source ) .'"></iframe>';
				return wp_kses( $iframe_html, $allowedHTMLtags );
			} else {
				return "Invalid puzzle type is present in the shortcode. Please use the correct shortcode from your PuzzleMe dashboard.";
			}
		} else {
			return "Both the set and puzzle type need to be present in the shortcode. Please use the correct shortcode from your PuzzleMe dashboard.";
		}
	}
	add_shortcode( 'puzzleme' , 'puzzleme_iframe_generator' );
?>